==> brobygger-li-2.3.2.tar.gz: brobygger-li-2.3.2/scraper/configuration.py <==
"""
Title     : configuration
Objective : Init and validate the configuration
Created by: Abdellah Janid
Created on: 5/12/20
"""

# Standard library imports
import json
import logging
from datetime import datetime
from pathlib import Path

# Related third party imports
import pandas as pd

# Import local applications
from scraper.configuration_schemas import LinkedinConfigSchema
from scraper.validation_tools import validate_schema

# Set level; change to DEBUG to log debug messages to file
logger_configuration = logging.getLogger('configuration')
logger_configuration.setLevel(logging.DEBUG)


def default_config():
    """

    Returns
    -------
    default_cfg : dict
    """
    default_cfg = {
        "miner": "",
        "hold_to_queued": False,
        "watchdog": True,
        "failed_limit": 4,
        "driver": {
            "timeout": 15,
            "scroll_increment": 300,
            "click_pause": {
                "min": 3,
                "max": 7
            },
            "scroll_pause": {
                "min": 3,
                "max": 7
            },
            "home_pause": {
                "min": 10,
                "max": 40
            }
        },
        "login_settings": {
            "login_check_flag": True,
            "login_check_type": "attribute",
            "login_page": "https://www.linkedin.com/login",
            "user": "",
            "css_user": "div.form__input--floating input[id='username']",
            "password": "",
            "css_password": "div.form__input--floating input[id='password']",
            "login_check": "",
            "css_login_check": "aside .msg-overlay-list-bubble .presence-entity",
            "css_login_tag": "img",
            "css_login_attribute": "title"


        },
        "links_list": {
            "schools": "schools_links_list.csv",
            "companies": "companies_links_list.csv",
            "employees": "employees_links_list.csv",
            "group_members": "group_members_links_list.csv",
            "my_connections": "my_connections_links_list.csv",
            "my_followers": "my_followers_links_list.csv",
            "people": "people_links_list.csv",
            "jobs_list": "jobs_list_links_list.csv",
            "jobs": "jobs_links_list.csv",
            "mutual_connections": "mutual_connections_links_list.csv",
            "connections_in_org": "connections_in_org_links_list.csv"
        },
        "get_endorsers_flag": False,
        "interest_popup": False,
        "popup_limit": 50
    }
    return default_cfg


def create_dirs(path, directories):
    """Creates the directories if they don't exist already

    Parameters
    ----------
    path: PosixPath
        path were to create the directories
    directories: list
        list of directories to create
    """
    for d in directories:
        Path(path, d).mkdir(exist_ok=True)
        logger_configuration.debug("created directory {} in {}".format(d, path))
        if d == "links_list":
            list_df = pd.DataFrame(
                columns=["status", "priority", "link", "id", "info", "file_name_source", "source_description", "timestamp_start",
                         "timestamp_end", "command", "error_msg", "tag", "added", "select"])
            list_path = Path(path, d) / str(Path(path, d).parents[1].name + "_links_list.csv")
            list_df.to_csv(list_path, index=False, sep=";")


def init_directories():
    """Creates the directories if they don't exist already
    Returns
    -------
    wd : str
        working directory path
    """
    home = Path.home()
    Path(home, "brobygger_li").mkdir(exist_ok=True)
    wd = Path(home, "brobygger_li")
    config = Path(home, "brobygger_li", "config.json")
    if config.exists() is False:
        with config.open("w") as fp:
            json.dump(default_config(), fp, indent=4, separators=(',', ': '))
    target_directories = ["people", "my_followers", "my_connections", "companies",
                          "employees", "group_members", "free_browsing", "schools",
                          "jobs_list", "jobs", "mutual_connections", "connections_in_org"
                          ]
    create_dirs(home / "brobygger_li", target_directories)
    data_directories = ["logs", "data", "watchdog", "config_validation_errors"]
    for d in target_directories:
        create_dirs(Path(home, "brobygger_li", d), data_directories)
    session_directories = ["profiles", "html", "failed_json_validations", "media", "links_list", "screenshots", "meta_data"]
    for d in target_directories:
        create_dirs(Path(home, "brobygger_li", d, "data"), session_directories)
        create_dirs(Path(home, "brobygger_li", d, "watchdog"), session_directories)
    return wd


def init_logger(target):
    """Set up the logger

    Parameters
    ----------
    target : str
        Path to folder to save log events
    """

    if logging.getLogger().hasHandlers():
        logging.getLogger().handlers.clear()

    # Setting up the logger configurations
    timestamp = datetime.now().strftime("%d_%m_%y_(%H_%M_%S)")
    log_filename = timestamp + ".log"  # set the name of logging file

    logging.basicConfig(filename=Path(Path.home(), "brobygger_li", target, "logs", log_filename),
                        filemode="a",
                        level=logging.INFO,
                        format='%(levelname)-12s , %(asctime)s , %(name)-12s , %(message)s',
                        datefmt='%d/%m/%y %H:%M:%S')

    # define a Handler which writes INFO messages or higher to the sys.stderr
    console = logging.StreamHandler()
    # set level to DEBUG if you want to see DEBUG info into the console
    console.setLevel(logging.DEBUG)
    # set a format which is simpler for console use
    formatter = logging.Formatter('%(levelname)-12s , %(asctime)s , %(name)-12s , %(message)s')
    # tell the handler to use this format
    console.setFormatter(formatter)
    # add the handler to the root logger
    logging.getLogger('').addHandler(console)


def init_configuration(target):
    """Initialize the configuration

    Parameters
    ----------
    target: str
        target to scrape
    Returns
    -------
    config : dict
        returns a dictionary of the configuration
    """
    config_path = Path(Path.home(), "brobygger_li", "config.json")
    with config_path.open() as fp:
        config = json.load(fp)

    init_logger(target)

    validated_config = validate_schema(LinkedinConfigSchema,
                                       config,
                                       Path(Path.home(), "brobygger_li", target, "config_validation_errors"),
                                       "linkedin_config_validation"
                                       )
    logger_configuration.info("Configuration loaded from: " + str(config_path))
    return json.loads(validated_config.json())

==> brobygger-li-2.5.1.tar.gz: brobygger-li-2.5.1/scraper/configuration.py <==
"""
Title     : configuration
Objective : Init and validate the configuration
Created by: Abdellah Janid
Created on: 5/12/20
"""

# Standard library imports
import json
import logging
from datetime import datetime
from pathlib import Path

# Related third party imports
import pandas as pd

# Import local applications
from scraper.configuration_schemas import LinkedinConfigSchema
from scraper.validation_tools import validate_schema

# Set level; change to DEBUG to log debug messages to file
logger_configuration = logging.getLogger('configuration')
logger_configuration.setLevel(logging.DEBUG)


def default_config():
    """

    Returns
    -------
    default_cfg : dict
    """
    default_cfg = {
        "miner": "",
        "hold_to_queued": False,
        "watchdog": True,
        "failed_limit": 4,
        "driver": {
            "timeout": 15,
            "scroll_increment": 300,
            "click_pause": {
                "min": 3,
                "max": 7
            },
            "scroll_pause": {
                "min": 3,
                "max": 7
            },
            "home_pause": {
                "min": 10,
                "max": 40
            }
        },
        "login_settings": {
            "login_check_flag": True,
            "login_check_type": "attribute",
            "login_page": "https://www.linkedin.com/login",
            "user": "",
            "css_user": "div.form__input--floating input[id='username']",
            "password": "",
            "css_password": "div.form__input--floating input[id='password']",
            "login_check": "",
            "css_login_check": "aside .msg-overlay-list-bubble .presence-entity",
            "css_login_tag": "img",
            "css_login_attribute": "title"


        },
        "links_list": {
            "schools": "schools_links_list.csv",
            "companies": "companies_links_list.csv",
            "employees": "employees_links_list.csv",
            "group_members": "group_members_links_list.csv",
            "my_connections": "my_connections_links_list.csv",
            "my_followers": "my_followers_links_list.csv",
            "people": "people_links_list.csv",
            "jobs_list": "jobs_list_links_list.csv",
            "jobs": "jobs_links_list.csv",
            "mutual_connections": "mutual_connections_links_list.csv",
            "connections_in_org": "connections_in_org_links_list.csv"
        },
        "get_endorsers_flag": False,
        "interest_popup": False,
        "popup_limit": 50
    }
    return default_cfg


def creatqe_dirs(path, directories):
    """Creates the directories if they don't exist already

    Parameters
    ----------
    path: PosixPath
        path were to create the directories
    directories: list
        list of directories to create
    """
    for d in directories:
        Path(path, d).mkdir(exist_ok=True)
        logger_configuration.debug("created directory {} in {}".format(d, path))
        if d == "links_list":
            list_df = pd.DataFrame(
                columns=["status", "priority", "link", "id", "info", "file_name_source", "source_description", "timestamp_start",
                         "timestamp_end", "command", "error_msg", "tag", "added", "select"])
            list_path = Path(path, d) / str(Path(path, d).parents[1].name + "_links_list.csv")
            list_df.to_csv(list_path, index=False, sep=";")


def init_directories():
    """Creates the directories if they don't exist already
    Returns
    -------
    wd : str
        working directory path
    """
    home = Path.home()
    Path(home, "brobygger_li").mkdir(exist_ok=True)
    wd = Path(home, "brobygger_li")
    config = Path(home, "brobygger_li", "config.json")
    if config.exists() is False:
        with config.open("w") as fp:
            json.dump(default_config(), fp, indent=4, separators=(',', ': '))
    target_directories = ["people", "my_followers", "my_connections", "companies",
                          "employees", "group_members", "free_browsing", "schools",
                          "jobs_list", "jobs", "mutual_connections", "connections_in_org"
                          ]
    create_dirs(home / "brobygger_li", target_directories)
    data_directories = ["logs", "data", "watchdog", "config_validation_errors"]
    for d in target_directories:
        create_dirs(Path(home, "brobygger_li", d), data_directories)
    session_directories = ["profiles", "html", "failed_json_validations", "media", "links_list", "screenshots", "meta_data"]
    for d in target_directories:
        create_dirs(Path(home, "brobygger_li", d, "data"), session_directories)
        create_dirs(Path(home, "brobygger_li", d, "watchdog"), session_directories)
    return wd


def init_logger(target):
    """Set up the logger

    Parameters
    ----------
    target : str
        Path to folder to save log events
    """

    if logging.getLogger().hasHandlers():
        logging.getLogger().handlers.clear()

    # Setting up the logger configurations
    timestamp = datetime.now().strftime("%d_%m_%y_(%H_%M_%S)")
    log_filename = timestamp + ".log"  # set the name of logging file

    logging.basicConfig(filename=Path(Path.home(), "brobygger_li", target, "logs", log_filename),
                        filemode="a",
                        level=logging.INFO,
                        format='%(levelname)-12s , %(asctime)s , %(name)-12s , %(message)s',
                        datefmt='%d/%m/%y %H:%M:%S')

    # define a Handler which writes INFO messages or higher to the sys.stderr
    console = logging.StreamHandler()
    # set level to DEBUG if you want to see DEBUG info into the console
    console.setLevel(logging.DEBUG)
    # set a format which is simpler for console use
    formatter = logging.Formatter('%(levelname)-12s , %(asctime)s , %(name)-12s , %(message)s')
    # tell the handler to use this format
    console.setFormatter(formatter)
    # add the handler to the root logger
    logging.getLogger('').addHandler(console)


def init_configuration(target):
    """Initialize the configuration

    Parameters
    ----------
    target: str
        target to scrape
    Returns
    -------
    config : dict
        returns a dictionary of the configuration
    """
    config_path = Path(Path.home(), "brobygger_li", "config.json")
    with config_path.open() as fp:
        config = json.load(fp)

    init_logger(target)

    validated_config = validate_schema(LinkedinConfigSchema,
                                       config,
                                       Path(Path.home(), "brobygger_li", target, "config_validation_errors"),
                                       "linkedin_config_validation"
                                       )
    logger_configuration.info("Configuration loaded from: " + str(config_path))
    return json.loads(validated_config.json())
